@@ -252,10 +252,6 @@ class XRedis(Singleton):
         return conn.zadd(z_name, {
             member: val
         })
-    
-    async def zrem(self, z_name, member):
-        conn = self.__get_connection()
-        return await conn.zrem(z_name, member)
         
     def zrange(self, z_name, score_min, score_max):
         conn = self._get_connection()
@@ -472,7 +468,9 @@ class XRedisAsync(Singleton):
     
     async def zadd(self, z_name, member, val):
         conn = self.__get_connection()
-        return await conn.zadd(z_name, member, val)
+        return await conn.zadd(z_name, {
+            member: val
+        })
     
     async def zrem(self, z_name, member):
         conn = self.__get_connection()
